/* SPDX-License-Identifier: BSD-3-Clause
 * Copyright(c) 2014-2023 Broadcom
 * All rights reserved.
 */

#include "ulp_template_db_enum.h"
#include "ulp_template_db_field.h"
#include "ulp_template_struct.h"
#include "ulp_template_db_tbl.h"

/* Define the template match patterns */
/*
 * List of protocol matches
 */
struct bnxt_ulp_class_match_info ulp_class_match_list[] = {
	[1] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV6 |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB258000000000000,
	.field_exclude_bitmap = 0x2000000000000000,
	.class_tid = 1,
	.flow_pattern_id = 0,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[44] = 5,
		[46] = 6,
		[48] = 7,
		[50] = 8,
		[52] = 9,
		[54] = 10,
		[56] = 11,
		[58] = 12,
		},
	},
	[2] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB216000000000000,
	.field_exclude_bitmap = 0x2000000000000000,
	.class_tid = 1,
	.flow_pattern_id = 0,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 5,
		[26] = 6,
		[28] = 7,
		[30] = 8,
		[32] = 9,
		[34] = 10,
		[36] = 11,
		[38] = 12,
		[40] = 13,
		[42] = 14,
		},
	},
	[3] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_OO_VLAN |
		BNXT_ULP_HDR_BIT_O_IPV6 |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB24B000000000000,
	.field_exclude_bitmap = 0x2000000000000000,
	.class_tid = 1,
	.flow_pattern_id = 0,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[44] = 8,
		[46] = 9,
		[48] = 10,
		[50] = 11,
		[52] = 12,
		[54] = 13,
		[56] = 14,
		[58] = 15,
		[100] = 5,
		[104] = 6,
		[108] = 7,
		},
	},
	[4] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_OO_VLAN |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB242C00000000000,
	.field_exclude_bitmap = 0x2000000000000000,
	.class_tid = 1,
	.flow_pattern_id = 0,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 8,
		[26] = 9,
		[28] = 10,
		[30] = 11,
		[32] = 12,
		[34] = 13,
		[36] = 14,
		[38] = 15,
		[40] = 16,
		[42] = 17,
		[100] = 5,
		[104] = 6,
		[108] = 7,
		},
	},
	[5] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV6 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB25E000000000000,
	.field_exclude_bitmap = 0x2000000000000000,
	.class_tid = 1,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[44] = 5,
		[46] = 6,
		[48] = 7,
		[50] = 8,
		[52] = 9,
		[54] = 10,
		[56] = 11,
		[58] = 12,
		[92] = 13,
		[94] = 14,
		[96] = 15,
		[98] = 16,
		},
	},
	[6] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB217800000000000,
	.field_exclude_bitmap = 0x2000000000000000,
	.class_tid = 1,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 5,
		[26] = 6,
		[28] = 7,
		[30] = 8,
		[32] = 9,
		[34] = 10,
		[36] = 11,
		[38] = 12,
		[40] = 13,
		[42] = 14,
		[92] = 15,
		[94] = 16,
		[96] = 17,
		[98] = 18,
		},
	},
	[7] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_OO_VLAN |
		BNXT_ULP_HDR_BIT_O_IPV6 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB24BC00000000000,
	.field_exclude_bitmap = 0x2000000000000000,
	.class_tid = 1,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[44] = 8,
		[46] = 9,
		[48] = 10,
		[50] = 11,
		[52] = 12,
		[54] = 13,
		[56] = 14,
		[58] = 15,
		[92] = 16,
		[94] = 17,
		[96] = 18,
		[98] = 19,
		[100] = 5,
		[104] = 6,
		[108] = 7,
		},
	},
	[8] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_OO_VLAN |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB242F00000000000,
	.field_exclude_bitmap = 0x2000000000000000,
	.class_tid = 1,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 8,
		[26] = 9,
		[28] = 10,
		[30] = 11,
		[32] = 12,
		[34] = 13,
		[36] = 14,
		[38] = 15,
		[40] = 16,
		[42] = 17,
		[92] = 18,
		[94] = 19,
		[96] = 20,
		[98] = 21,
		[100] = 5,
		[104] = 6,
		[108] = 7,
		},
	},
	[9] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV6 |
		BNXT_ULP_HDR_BIT_O_TCP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB25E200000000000,
	.field_exclude_bitmap = 0x2000000000000000,
	.class_tid = 1,
	.flow_pattern_id = 2,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[44] = 5,
		[46] = 6,
		[48] = 7,
		[50] = 8,
		[52] = 9,
		[54] = 10,
		[56] = 11,
		[58] = 12,
		[74] = 13,
		[76] = 14,
		[78] = 15,
		[80] = 16,
		[82] = 17,
		[84] = 18,
		[86] = 19,
		[88] = 20,
		[90] = 21,
		},
	},
	[10] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_TCP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB217880000000000,
	.field_exclude_bitmap = 0x2000000000000000,
	.class_tid = 1,
	.flow_pattern_id = 2,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 5,
		[26] = 6,
		[28] = 7,
		[30] = 8,
		[32] = 9,
		[34] = 10,
		[36] = 11,
		[38] = 12,
		[40] = 13,
		[42] = 14,
		[74] = 15,
		[76] = 16,
		[78] = 17,
		[80] = 18,
		[82] = 19,
		[84] = 20,
		[86] = 21,
		[88] = 22,
		[90] = 23,
		},
	},
	[11] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_OO_VLAN |
		BNXT_ULP_HDR_BIT_O_IPV6 |
		BNXT_ULP_HDR_BIT_O_TCP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB24BC40000000000,
	.field_exclude_bitmap = 0x2000000000000000,
	.class_tid = 1,
	.flow_pattern_id = 2,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[44] = 8,
		[46] = 9,
		[48] = 10,
		[50] = 11,
		[52] = 12,
		[54] = 13,
		[56] = 14,
		[58] = 15,
		[74] = 16,
		[76] = 17,
		[78] = 18,
		[80] = 19,
		[82] = 20,
		[84] = 21,
		[86] = 22,
		[88] = 23,
		[90] = 24,
		[100] = 5,
		[104] = 6,
		[108] = 7,
		},
	},
	[12] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_OO_VLAN |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_TCP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB242F10000000000,
	.field_exclude_bitmap = 0x2000000000000000,
	.class_tid = 1,
	.flow_pattern_id = 2,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 8,
		[26] = 9,
		[28] = 10,
		[30] = 11,
		[32] = 12,
		[34] = 13,
		[36] = 14,
		[38] = 15,
		[40] = 16,
		[42] = 17,
		[74] = 18,
		[76] = 19,
		[78] = 20,
		[80] = 21,
		[82] = 22,
		[84] = 23,
		[86] = 24,
		[88] = 25,
		[90] = 26,
		[100] = 5,
		[104] = 6,
		[108] = 7,
		},
	},
	[13] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x2002000000000000,
	.field_opt_bitmap = 0x8000800000000000,
	.field_exclude_bitmap = 0x2000000000000000,
	.class_tid = 1,
	.flow_pattern_id = 3,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 5,
		[26] = 6,
		[28] = 7,
		[30] = 8,
		[32] = 9,
		[34] = 10,
		[36] = 11,
		[38] = 12,
		[40] = 13,
		[42] = 14,
		[92] = 15,
		[94] = 16,
		[96] = 17,
		[98] = 18,
		[112] = 19,
		[113] = 20,
		[114] = 21,
		[115] = 22,
		},
	},
	[14] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_SVIF |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0x8000000000000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 1,
	.flow_pattern_id = 4,
	.field_list = {
		[1] = 1,
		},
	},
	[15] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_F1 |
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x2002800000000000,
	.field_opt_bitmap = 0x9000000000000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 0,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 5,
		[26] = 6,
		[28] = 7,
		[30] = 8,
		[32] = 9,
		[34] = 10,
		[36] = 11,
		[38] = 12,
		[40] = 13,
		[42] = 14,
		[92] = 15,
		[94] = 16,
		[96] = 17,
		[98] = 18,
		[112] = 19,
		[113] = 20,
		[114] = 21,
		[115] = 22,
		},
	},
	[16] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV6 |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x30200000000000,
	.field_opt_bitmap = 0x80040C0600000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[7] = 20,
		[9] = 21,
		[11] = 22,
		[24] = 2,
		[26] = 3,
		[28] = 4,
		[30] = 5,
		[32] = 6,
		[34] = 7,
		[36] = 8,
		[38] = 9,
		[40] = 10,
		[42] = 11,
		[45] = 23,
		[47] = 24,
		[49] = 25,
		[51] = 26,
		[53] = 27,
		[55] = 28,
		[57] = 29,
		[59] = 30,
		[92] = 12,
		[94] = 13,
		[96] = 14,
		[98] = 15,
		[112] = 16,
		[113] = 17,
		[114] = 18,
		[115] = 19,
		},
	},
	[17] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV4 |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x30200000000000,
	.field_opt_bitmap = 0x80040C0180000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[7] = 20,
		[9] = 21,
		[11] = 22,
		[24] = 2,
		[25] = 23,
		[26] = 3,
		[27] = 24,
		[28] = 4,
		[29] = 25,
		[30] = 5,
		[31] = 26,
		[32] = 6,
		[33] = 27,
		[34] = 7,
		[35] = 28,
		[36] = 8,
		[37] = 29,
		[38] = 9,
		[39] = 30,
		[40] = 10,
		[41] = 31,
		[42] = 11,
		[43] = 32,
		[92] = 12,
		[94] = 13,
		[96] = 14,
		[98] = 15,
		[112] = 16,
		[113] = 17,
		[114] = 18,
		[115] = 19,
		},
	},
	[18] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV6 |
		BNXT_ULP_HDR_BIT_I_TCP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x30200000000000,
	.field_opt_bitmap = 0x80040C0780000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[7] = 20,
		[9] = 21,
		[11] = 22,
		[24] = 2,
		[26] = 3,
		[28] = 4,
		[30] = 5,
		[32] = 6,
		[34] = 7,
		[36] = 8,
		[38] = 9,
		[40] = 10,
		[42] = 11,
		[45] = 23,
		[47] = 24,
		[49] = 25,
		[51] = 26,
		[53] = 27,
		[55] = 28,
		[57] = 29,
		[59] = 30,
		[75] = 31,
		[77] = 32,
		[79] = 33,
		[81] = 34,
		[83] = 35,
		[85] = 36,
		[87] = 37,
		[89] = 38,
		[91] = 39,
		[92] = 12,
		[94] = 13,
		[96] = 14,
		[98] = 15,
		[112] = 16,
		[113] = 17,
		[114] = 18,
		[115] = 19,
		},
	},
	[19] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV4 |
		BNXT_ULP_HDR_BIT_I_TCP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x30200000000000,
	.field_opt_bitmap = 0x80040C01E0000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[7] = 20,
		[9] = 21,
		[11] = 22,
		[24] = 2,
		[25] = 23,
		[26] = 3,
		[27] = 24,
		[28] = 4,
		[29] = 25,
		[30] = 5,
		[31] = 26,
		[32] = 6,
		[33] = 27,
		[34] = 7,
		[35] = 28,
		[36] = 8,
		[37] = 29,
		[38] = 9,
		[39] = 30,
		[40] = 10,
		[41] = 31,
		[42] = 11,
		[43] = 32,
		[75] = 33,
		[77] = 34,
		[79] = 35,
		[81] = 36,
		[83] = 37,
		[85] = 38,
		[87] = 39,
		[89] = 40,
		[91] = 41,
		[92] = 12,
		[94] = 13,
		[96] = 14,
		[98] = 15,
		[112] = 16,
		[113] = 17,
		[114] = 18,
		[115] = 19,
		},
	},
	[20] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV6 |
		BNXT_ULP_HDR_BIT_I_UDP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x30200000000000,
	.field_opt_bitmap = 0x80040C0780000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[7] = 20,
		[9] = 21,
		[11] = 22,
		[24] = 2,
		[26] = 3,
		[28] = 4,
		[30] = 5,
		[32] = 6,
		[34] = 7,
		[36] = 8,
		[38] = 9,
		[40] = 10,
		[42] = 11,
		[45] = 23,
		[47] = 24,
		[49] = 25,
		[51] = 26,
		[53] = 27,
		[55] = 28,
		[57] = 29,
		[59] = 30,
		[92] = 12,
		[93] = 31,
		[94] = 13,
		[95] = 32,
		[96] = 14,
		[97] = 33,
		[98] = 15,
		[99] = 34,
		[112] = 16,
		[113] = 17,
		[114] = 18,
		[115] = 19,
		},
	},
	[21] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV4 |
		BNXT_ULP_HDR_BIT_I_UDP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x30200000000000,
	.field_opt_bitmap = 0x80040C01E0000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[7] = 20,
		[9] = 21,
		[11] = 22,
		[24] = 2,
		[25] = 23,
		[26] = 3,
		[27] = 24,
		[28] = 4,
		[29] = 25,
		[30] = 5,
		[31] = 26,
		[32] = 6,
		[33] = 27,
		[34] = 7,
		[35] = 28,
		[36] = 8,
		[37] = 29,
		[38] = 9,
		[39] = 30,
		[40] = 10,
		[41] = 31,
		[42] = 11,
		[43] = 32,
		[92] = 12,
		[93] = 33,
		[94] = 13,
		[95] = 34,
		[96] = 14,
		[97] = 35,
		[98] = 15,
		[99] = 36,
		[112] = 16,
		[113] = 17,
		[114] = 18,
		[115] = 19,
		},
	},
	[22] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV4 |
		BNXT_ULP_HDR_BIT_I_ICMP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x30200000000000,
	.field_opt_bitmap = 0x80040C0180000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 2,
	.field_list = {
		[1] = 1,
		[7] = 20,
		[9] = 21,
		[11] = 22,
		[15] = 33,
		[17] = 34,
		[19] = 35,
		[21] = 36,
		[23] = 37,
		[24] = 2,
		[25] = 23,
		[26] = 3,
		[27] = 24,
		[28] = 4,
		[29] = 25,
		[30] = 5,
		[31] = 26,
		[32] = 6,
		[33] = 27,
		[34] = 7,
		[35] = 28,
		[36] = 8,
		[37] = 29,
		[38] = 9,
		[39] = 30,
		[40] = 10,
		[41] = 31,
		[42] = 11,
		[43] = 32,
		[92] = 12,
		[94] = 13,
		[96] = 14,
		[98] = 15,
		[112] = 16,
		[113] = 17,
		[114] = 18,
		[115] = 19,
		},
	},
	[23] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV6 |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x2006040000000000,
	.field_opt_bitmap = 0x90008180C0000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 3,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[7] = 23,
		[8] = 3,
		[9] = 24,
		[10] = 4,
		[11] = 25,
		[24] = 5,
		[26] = 6,
		[28] = 7,
		[30] = 8,
		[32] = 9,
		[34] = 10,
		[36] = 11,
		[38] = 12,
		[40] = 13,
		[42] = 14,
		[45] = 26,
		[47] = 27,
		[49] = 28,
		[51] = 29,
		[53] = 30,
		[55] = 31,
		[57] = 32,
		[59] = 33,
		[92] = 15,
		[94] = 16,
		[96] = 17,
		[98] = 18,
		[112] = 19,
		[113] = 20,
		[114] = 21,
		[115] = 22,
		},
	},
	[24] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV4 |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x2006040000000000,
	.field_opt_bitmap = 0x9000818030000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 3,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[7] = 23,
		[8] = 3,
		[9] = 24,
		[10] = 4,
		[11] = 25,
		[24] = 5,
		[25] = 26,
		[26] = 6,
		[27] = 27,
		[28] = 7,
		[29] = 28,
		[30] = 8,
		[31] = 29,
		[32] = 9,
		[33] = 30,
		[34] = 10,
		[35] = 31,
		[36] = 11,
		[37] = 32,
		[38] = 12,
		[39] = 33,
		[40] = 13,
		[41] = 34,
		[42] = 14,
		[43] = 35,
		[92] = 15,
		[94] = 16,
		[96] = 17,
		[98] = 18,
		[112] = 19,
		[113] = 20,
		[114] = 21,
		[115] = 22,
		},
	},
	[25] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV6 |
		BNXT_ULP_HDR_BIT_I_TCP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x2006040000000000,
	.field_opt_bitmap = 0x90008180F0000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 3,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[7] = 23,
		[8] = 3,
		[9] = 24,
		[10] = 4,
		[11] = 25,
		[24] = 5,
		[26] = 6,
		[28] = 7,
		[30] = 8,
		[32] = 9,
		[34] = 10,
		[36] = 11,
		[38] = 12,
		[40] = 13,
		[42] = 14,
		[45] = 26,
		[47] = 27,
		[49] = 28,
		[51] = 29,
		[53] = 30,
		[55] = 31,
		[57] = 32,
		[59] = 33,
		[75] = 34,
		[77] = 35,
		[79] = 36,
		[81] = 37,
		[83] = 38,
		[85] = 39,
		[87] = 40,
		[89] = 41,
		[91] = 42,
		[92] = 15,
		[94] = 16,
		[96] = 17,
		[98] = 18,
		[112] = 19,
		[113] = 20,
		[114] = 21,
		[115] = 22,
		},
	},
	[26] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV4 |
		BNXT_ULP_HDR_BIT_I_TCP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x2006040000000000,
	.field_opt_bitmap = 0x900081803C000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 3,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[7] = 23,
		[8] = 3,
		[9] = 24,
		[10] = 4,
		[11] = 25,
		[24] = 5,
		[25] = 26,
		[26] = 6,
		[27] = 27,
		[28] = 7,
		[29] = 28,
		[30] = 8,
		[31] = 29,
		[32] = 9,
		[33] = 30,
		[34] = 10,
		[35] = 31,
		[36] = 11,
		[37] = 32,
		[38] = 12,
		[39] = 33,
		[40] = 13,
		[41] = 34,
		[42] = 14,
		[43] = 35,
		[75] = 36,
		[77] = 37,
		[79] = 38,
		[81] = 39,
		[83] = 40,
		[85] = 41,
		[87] = 42,
		[89] = 43,
		[91] = 44,
		[92] = 15,
		[94] = 16,
		[96] = 17,
		[98] = 18,
		[112] = 19,
		[113] = 20,
		[114] = 21,
		[115] = 22,
		},
	},
	[27] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV6 |
		BNXT_ULP_HDR_BIT_I_UDP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x2006040000000000,
	.field_opt_bitmap = 0x90008180F0000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 3,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[7] = 23,
		[8] = 3,
		[9] = 24,
		[10] = 4,
		[11] = 25,
		[24] = 5,
		[26] = 6,
		[28] = 7,
		[30] = 8,
		[32] = 9,
		[34] = 10,
		[36] = 11,
		[38] = 12,
		[40] = 13,
		[42] = 14,
		[45] = 26,
		[47] = 27,
		[49] = 28,
		[51] = 29,
		[53] = 30,
		[55] = 31,
		[57] = 32,
		[59] = 33,
		[92] = 15,
		[93] = 34,
		[94] = 16,
		[95] = 35,
		[96] = 17,
		[97] = 36,
		[98] = 18,
		[99] = 37,
		[112] = 19,
		[113] = 20,
		[114] = 21,
		[115] = 22,
		},
	},
	[28] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV4 |
		BNXT_ULP_HDR_BIT_I_UDP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x2006040000000000,
	.field_opt_bitmap = 0x900081803C000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 3,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[7] = 23,
		[8] = 3,
		[9] = 24,
		[10] = 4,
		[11] = 25,
		[24] = 5,
		[25] = 26,
		[26] = 6,
		[27] = 27,
		[28] = 7,
		[29] = 28,
		[30] = 8,
		[31] = 29,
		[32] = 9,
		[33] = 30,
		[34] = 10,
		[35] = 31,
		[36] = 11,
		[37] = 32,
		[38] = 12,
		[39] = 33,
		[40] = 13,
		[41] = 34,
		[42] = 14,
		[43] = 35,
		[92] = 15,
		[93] = 36,
		[94] = 16,
		[95] = 37,
		[96] = 17,
		[97] = 38,
		[98] = 18,
		[99] = 39,
		[112] = 19,
		[113] = 20,
		[114] = 21,
		[115] = 22,
		},
	},
	[29] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_HDR_BIT_T_VXLAN |
		BNXT_ULP_HDR_BIT_I_ETH |
		BNXT_ULP_HDR_BIT_I_IPV4 |
		BNXT_ULP_HDR_BIT_I_ICMP |
		BNXT_ULP_FLOW_DIR_BITMASK_ING },
	.field_man_bitmap = 0x2006040000000000,
	.field_opt_bitmap = 0x9000818030000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 2,
	.flow_pattern_id = 4,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[7] = 23,
		[8] = 3,
		[9] = 24,
		[10] = 4,
		[11] = 25,
		[15] = 36,
		[17] = 37,
		[19] = 38,
		[21] = 39,
		[23] = 40,
		[24] = 5,
		[25] = 26,
		[26] = 6,
		[27] = 27,
		[28] = 7,
		[29] = 28,
		[30] = 8,
		[31] = 29,
		[32] = 9,
		[33] = 30,
		[34] = 10,
		[35] = 31,
		[36] = 11,
		[37] = 32,
		[38] = 12,
		[39] = 33,
		[40] = 13,
		[41] = 34,
		[42] = 14,
		[43] = 35,
		[92] = 15,
		[94] = 16,
		[96] = 17,
		[98] = 18,
		[112] = 19,
		[113] = 20,
		[114] = 21,
		[115] = 22,
		},
	},
	[30] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV6 |
		BNXT_ULP_FLOW_DIR_BITMASK_EGR },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB258000000000000,
	.field_exclude_bitmap = 0x1000000000000000,
	.class_tid = 3,
	.flow_pattern_id = 0,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[44] = 5,
		[46] = 6,
		[48] = 7,
		[50] = 8,
		[52] = 9,
		[54] = 10,
		[56] = 11,
		[58] = 12,
		},
	},
	[31] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_FLOW_DIR_BITMASK_EGR },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB216000000000000,
	.field_exclude_bitmap = 0x1000000000000000,
	.class_tid = 3,
	.flow_pattern_id = 0,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 5,
		[26] = 6,
		[28] = 7,
		[30] = 8,
		[32] = 9,
		[34] = 10,
		[36] = 11,
		[38] = 12,
		[40] = 13,
		[42] = 14,
		},
	},
	[32] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_OO_VLAN |
		BNXT_ULP_HDR_BIT_O_IPV6 |
		BNXT_ULP_FLOW_DIR_BITMASK_EGR },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB24B000000000000,
	.field_exclude_bitmap = 0x1000000000000000,
	.class_tid = 3,
	.flow_pattern_id = 0,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[44] = 8,
		[46] = 9,
		[48] = 10,
		[50] = 11,
		[52] = 12,
		[54] = 13,
		[56] = 14,
		[58] = 15,
		[100] = 5,
		[104] = 6,
		[108] = 7,
		},
	},
	[33] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_OO_VLAN |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_FLOW_DIR_BITMASK_EGR },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB242C00000000000,
	.field_exclude_bitmap = 0x1000000000000000,
	.class_tid = 3,
	.flow_pattern_id = 0,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 8,
		[26] = 9,
		[28] = 10,
		[30] = 11,
		[32] = 12,
		[34] = 13,
		[36] = 14,
		[38] = 15,
		[40] = 16,
		[42] = 17,
		[100] = 5,
		[104] = 6,
		[108] = 7,
		},
	},
	[34] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV6 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_FLOW_DIR_BITMASK_EGR },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB25E000000000000,
	.field_exclude_bitmap = 0x1000000000000000,
	.class_tid = 3,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[44] = 5,
		[46] = 6,
		[48] = 7,
		[50] = 8,
		[52] = 9,
		[54] = 10,
		[56] = 11,
		[58] = 12,
		[92] = 13,
		[94] = 14,
		[96] = 15,
		[98] = 16,
		},
	},
	[35] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_FLOW_DIR_BITMASK_EGR },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB217800000000000,
	.field_exclude_bitmap = 0x1000000000000000,
	.class_tid = 3,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 5,
		[26] = 6,
		[28] = 7,
		[30] = 8,
		[32] = 9,
		[34] = 10,
		[36] = 11,
		[38] = 12,
		[40] = 13,
		[42] = 14,
		[92] = 15,
		[94] = 16,
		[96] = 17,
		[98] = 18,
		},
	},
	[36] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_OO_VLAN |
		BNXT_ULP_HDR_BIT_O_IPV6 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_FLOW_DIR_BITMASK_EGR },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB24BC00000000000,
	.field_exclude_bitmap = 0x1000000000000000,
	.class_tid = 3,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[44] = 8,
		[46] = 9,
		[48] = 10,
		[50] = 11,
		[52] = 12,
		[54] = 13,
		[56] = 14,
		[58] = 15,
		[92] = 16,
		[94] = 17,
		[96] = 18,
		[98] = 19,
		[100] = 5,
		[104] = 6,
		[108] = 7,
		},
	},
	[37] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_OO_VLAN |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_UDP |
		BNXT_ULP_FLOW_DIR_BITMASK_EGR },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB242F00000000000,
	.field_exclude_bitmap = 0x1000000000000000,
	.class_tid = 3,
	.flow_pattern_id = 1,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 8,
		[26] = 9,
		[28] = 10,
		[30] = 11,
		[32] = 12,
		[34] = 13,
		[36] = 14,
		[38] = 15,
		[40] = 16,
		[42] = 17,
		[92] = 18,
		[94] = 19,
		[96] = 20,
		[98] = 21,
		[100] = 5,
		[104] = 6,
		[108] = 7,
		},
	},
	[38] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV6 |
		BNXT_ULP_HDR_BIT_O_TCP |
		BNXT_ULP_FLOW_DIR_BITMASK_EGR },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB25E200000000000,
	.field_exclude_bitmap = 0x1000000000000000,
	.class_tid = 3,
	.flow_pattern_id = 2,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[44] = 5,
		[46] = 6,
		[48] = 7,
		[50] = 8,
		[52] = 9,
		[54] = 10,
		[56] = 11,
		[58] = 12,
		[74] = 13,
		[76] = 14,
		[78] = 15,
		[80] = 16,
		[82] = 17,
		[84] = 18,
		[86] = 19,
		[88] = 20,
		[90] = 21,
		},
	},
	[39] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_TCP |
		BNXT_ULP_FLOW_DIR_BITMASK_EGR },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB217880000000000,
	.field_exclude_bitmap = 0x1000000000000000,
	.class_tid = 3,
	.flow_pattern_id = 2,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 5,
		[26] = 6,
		[28] = 7,
		[30] = 8,
		[32] = 9,
		[34] = 10,
		[36] = 11,
		[38] = 12,
		[40] = 13,
		[42] = 14,
		[74] = 15,
		[76] = 16,
		[78] = 17,
		[80] = 18,
		[82] = 19,
		[84] = 20,
		[86] = 21,
		[88] = 22,
		[90] = 23,
		},
	},
	[40] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_OO_VLAN |
		BNXT_ULP_HDR_BIT_O_IPV6 |
		BNXT_ULP_HDR_BIT_O_TCP |
		BNXT_ULP_FLOW_DIR_BITMASK_EGR },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB24BC40000000000,
	.field_exclude_bitmap = 0x1000000000000000,
	.class_tid = 3,
	.flow_pattern_id = 2,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[44] = 8,
		[46] = 9,
		[48] = 10,
		[50] = 11,
		[52] = 12,
		[54] = 13,
		[56] = 14,
		[58] = 15,
		[74] = 16,
		[76] = 17,
		[78] = 18,
		[80] = 19,
		[82] = 20,
		[84] = 21,
		[86] = 22,
		[88] = 23,
		[90] = 24,
		[100] = 5,
		[104] = 6,
		[108] = 7,
		},
	},
	[41] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_O_ETH |
		BNXT_ULP_HDR_BIT_OO_VLAN |
		BNXT_ULP_HDR_BIT_O_IPV4 |
		BNXT_ULP_HDR_BIT_O_TCP |
		BNXT_ULP_FLOW_DIR_BITMASK_EGR },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0xB242F10000000000,
	.field_exclude_bitmap = 0x1000000000000000,
	.class_tid = 3,
	.flow_pattern_id = 2,
	.field_list = {
		[1] = 1,
		[6] = 2,
		[8] = 3,
		[10] = 4,
		[24] = 8,
		[26] = 9,
		[28] = 10,
		[30] = 11,
		[32] = 12,
		[34] = 13,
		[36] = 14,
		[38] = 15,
		[40] = 16,
		[42] = 17,
		[74] = 18,
		[76] = 19,
		[78] = 20,
		[80] = 21,
		[82] = 22,
		[84] = 23,
		[86] = 24,
		[88] = 25,
		[90] = 26,
		[100] = 5,
		[104] = 6,
		[108] = 7,
		},
	},
	[42] = {
	.app_id = 0,
	.hdr_bitmap = { .bits =
		BNXT_ULP_HDR_BIT_SVIF |
		BNXT_ULP_FLOW_DIR_BITMASK_EGR },
	.field_man_bitmap = 0x0,
	.field_opt_bitmap = 0x8000000000000000,
	.field_exclude_bitmap = 0x0,
	.class_tid = 3,
	.flow_pattern_id = 3,
	.field_list = {
		[1] = 1,
		},
	}
};

